@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafViewer;
-$Config::Model::Tk::LeafViewer::VERSION = '1.361';
+$Config::Model::Tk::LeafViewer::VERSION = '1.365';
 use strict;
 use warnings;
 use 5.10.1;
@@ -41,6 +41,7 @@ sub Populate {
         || die "LeafViewer: no -item, got ", keys %$args;
     my $path = delete $args->{-path}
         || die "LeafViewer: no -path, got ", keys %$args;
+    my $cme_font = delete $args->{-font};
 
     my $inst = $leaf->instance;
 
@@ -98,7 +99,7 @@ sub Populate {
     $cw->add_editor_button($path)->pack( @fxe1, -side => 'right', -anchor => 'n' );
 
     $cw->ConfigSpecs(
-
+        -font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],
         #-fill   => [ qw/SELF fill Fill both/],
         #-expand => [ qw/SELF expand Expand 1/],
         -relief      => [qw/SELF relief Relief groove/],
