@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor;
-$Config::Model::Tk::ListEditor::VERSION = '1.361';
+$Config::Model::Tk::ListEditor::VERSION = '1.365';
 use strict;
 use warnings;
 use Carp;
@@ -47,6 +47,7 @@ sub Populate {
         || die "ListEditor: no -item, got ", keys %$args;
 
     delete $args->{-path};
+    my $cme_font = delete $args->{-font};
 
     $cw->{store_cb} = delete $args->{-store_cb}
         or die __PACKAGE__, "no -store_cb";
@@ -168,6 +169,8 @@ sub Populate {
     $cw->{tklist} = $tklist;
     $cw->reset_value;
 
+    $cw->ConfigSpecs(-font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],);
+
     $cw->Tk::Frame::Populate($args);
 }
 
