@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListViewer;
-$Config::Model::Tk::ListViewer::VERSION = '1.351';
+$Config::Model::Tk::ListViewer::VERSION = '1.365';
 use strict;
 use warnings;
 use Carp;
@@ -37,6 +37,7 @@ sub Populate {
         || die "ListViewer: no -item, got ", keys %$args;
     my $path = delete $args->{-path}
         || die "ListViewer: no -path, got ", keys %$args;
+    my $cme_font = delete $args->{-font};
 
     $cw->add_header( View => $list )->pack(@fx);
 
@@ -60,11 +61,13 @@ sub Populate {
     $cw->add_annotation($list)->pack(@fx);
     $cw->add_warning( $list, 'view' )->pack(@fx);
     $cw->add_summary($list)->pack(@fx);
-    $cw->add_description($list)->pack(@fx);
+    $cw->add_description($list)->pack(@fbe1);
 
     $cw->add_info_button()->pack( -side => 'left', @fxe1 );
     $cw->add_editor_button($path)->pack( -side => 'right', @fxe1 );
 
+    $cw->ConfigSpecs(-font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],);
+
     $cw->SUPER::Populate($args);
 }
 
