@@ -1,17 +1,18 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::NodeViewer;
-$Config::Model::Tk::NodeViewer::VERSION = '1.356';
+$Config::Model::Tk::NodeViewer::VERSION = '1.365';
 use strict;
 use warnings;
 use Carp;
+use 5.10.1;
 
 use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
 use subs qw/menu_struct/;
@@ -36,6 +37,7 @@ sub Populate {
     my $node = $cw->{node} = delete $args->{-item}
         || die "NodeViewer: no -item, got ", keys %$args;
     my $path = delete $args->{-path};
+    my $cme_font = delete $args->{-font};
 
     $cw->add_header( View => $node )->pack(@fx);
 
@@ -67,7 +69,7 @@ sub Populate {
 
     if ( $node->parent ) {
         $cw->add_summary($node)->pack(@fx);
-        $cw->add_description($node)->pack(@fx);
+        $cw->add_description($node)->pack(@fbe1);
     }
     else {
         $cw->add_help( class => $node->get_help )->pack(@fx);
@@ -76,6 +78,8 @@ sub Populate {
     $cw->add_info_button()->pack( @fxe1, -side => 'left' );
     $cw->add_editor_button($path)->pack( @fxe1, -side => 'right' );
 
+    $cw->ConfigSpecs(-font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],);
+
     $cw->SUPER::Populate($args);
 }
 
@@ -92,19 +96,21 @@ sub reload {
 
     my %old_elt = %{ $cw->{elt_path} || {} };
 
-    foreach my $c ( $node->get_element_name() ) {
-        my $type = $node->element_type($c);
+    foreach my $elt_name ( $node->get_element_name() ) {
+        my $hl_name = $elt_name;
+        $hl_name =~ s/\./__/g; # make elt name compatible with Tk::HList
 
-        unless ( delete $old_elt{$c} ) {
+        my $type = $node->element_type($elt_name);
 
+        unless ( delete $old_elt{$hl_name} ) {
             # create item
-            $hl->add($c);
-            $cw->{elt_path}{$c} = 1;
+            $hl->add($hl_name);
+            $cw->{elt_path}{$hl_name} = 1;
 
-            $hl->itemCreate( $c, 0, -text => $c );
-            $hl->itemCreate( $c, 1, -text => $type );
+            $hl->itemCreate( $hl_name, 0, -text => $elt_name );
+            $hl->itemCreate( $hl_name, 1, -text => $type );
             $hl->itemCreate(
-                $c, 2,
+                $hl_name, 2,
                 -itemtype  => 'imagetext',
                 -text      => '',
                 -showimage => 0,
@@ -115,10 +121,10 @@ sub reload {
         if ( $type eq 'leaf' ) {
 
             # update displayed value
-            my $v = eval { $node->fetch_element_value($c) };
+            my $v = eval { $node->fetch_element_value($elt_name) };
             if ($@) {
                 $hl->itemConfigure(
-                    $c, 2,
+                    $hl_name, 2,
                     -showtext  => 0,
                     -showimage => 1,
                 );
@@ -126,7 +132,7 @@ sub reload {
             elsif ( defined $v ) {
                 substr( $v, 15 ) = '...' if length($v) > 15;
                 $hl->itemConfigure(
-                    $c, 2,
+                    $hl_name, 2,
                     -showtext  => 1,
                     -showimage => 0,
                     -text      => $v
