@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.351';
+$Config::Model::TkUI::VERSION = '1.365';
 use 5.10.1;
 use strict;
 use warnings;
@@ -21,6 +21,9 @@ use vars qw/$icon_path $error_img $warn_img/;
 use subs qw/menu_struct/;
 use Scalar::Util qw/weaken/;
 use Log::Log4perl 1.11;
+use Path::Tiny;
+use YAML qw/LoadFile DumpFile/;
+use File::HomeDir;
 
 use Pod::POM;
 use Pod::POM::View::Text;
@@ -31,11 +34,12 @@ use Tk::Photo;
 use Tk::PNG;    # required for Tk::Photo to be able to load pngs
 use Tk::DialogBox;
 use Tk::Adjuster;
+use Tk::FontDialog;
 
 use Tk::Pod;
 use Tk::Pod::Text;    # for findpod
 
-use Config::Model 2.074;
+use Config::Model 2.114; # Node::gist
 
 use Config::Model::Tk::LeafEditor;
 use Config::Model::Tk::CheckListEditor;
@@ -82,15 +86,41 @@ sub Tk::Error {
 
 use warnings "redefine";
 
+my $default_config = {
+    font => { -family =>  'DejaVu Sans', qw/-size -13 -weight normal/ }
+};
+
+my $main_window;
+my $config_path = path(File::HomeDir->my_home)->child('.cme/config/');
+my $config_file = $config_path->child('tkui.yml');
+
+$config_path -> mkpath;
+
+my $config = $config_file->is_file ? LoadFile($config_file) : $default_config ;
+
+# Tk::CmdLine::SetArguments( -font => $config->{font} ) ;
+
 sub ClassInit {
     my ( $class, $mw ) = @_;
-
+    $main_window = $mw;
     # ClassInit is often used to define bindings and/or other
     # resources shared by all instances, e.g., images.
 
     # cw->Advertise(name=>$widget);
 }
 
+sub set_font {
+    my $cw = shift;
+
+    my $tk_font = $main_window->FontDialog->Show;
+    if (defined $tk_font) {
+        $main_window->RefontTree(-font => $tk_font);
+        $config->{font} = {$tk_font->actual} ;
+        $cw->ConfigSpecs( -font => ['DESCENDANTS', 'font','Font', $tk_font ]);
+        DumpFile($config_file->stringify, $config);
+    }
+}
+
 sub Populate {
     my ( $cw, $args ) = @_;
 
@@ -130,6 +160,7 @@ sub Populate {
 
     # initialize internal attributes
     $cw->{location} = '';
+    $cw->{current_mode} = 'view';
 
     $cw->setup_scanner();
 
@@ -145,7 +176,7 @@ sub Populate {
         [ command => 'check for errors',     -command => sub { $cw->check(1) } ],
         [ command => 'check for warnings',   -command => sub { $cw->check( 1, 1 ) } ],
         [ command => 'show unsaved changes', -command => sub { $cw->show_changes; } ],
-        [ qw/command save   -command/, sub { $cw->save } ],
+        [ command => 'save (Ctrl-s)', -command => sub { $cw->save } ],
         [
             command  => 'save in dir ...',
             -command => sub { $cw->save_in_dir; }
@@ -158,21 +189,32 @@ sub Populate {
                 Tk::ObjScanner::scan_object( $cw->{root} );
                 }
         ],
-        [ qw/command quit   -command/, sub { $cw->quit } ],
+        [ command => 'quit (Ctrl-q)', -command => sub { $cw->quit } ],
     ];
     $menubar->cascade( -label => 'File', -menuitems => $file_items );
 
     $cw->add_help_menu($menubar);
 
+    $cw->bind( '<Control-s>', sub { $cw->save } );
+    $cw->bind( '<Control-q>', sub { $cw->quit } );
+    $cw->bind( '<Control-c>', sub { $cw->edit_copy } );
+    $cw->bind( '<Control-v>', sub { $cw->edit_paste } );
+    $cw->bind( '<Control-f>', sub { $cw->pack_find_widget } );
+
     my $edit_items = [
 
         # [ qw/command cut   -command/, sub{ $cw->edit_cut }],
-        [ command => 'copy (Ctrl-C)',  '-command', sub { $cw->edit_copy } ],
-        [ command => 'paste (Ctrl-V)', '-command', sub { $cw->edit_paste } ],
-        [ command => 'find (Ctrl-F)',  '-command', sub { $cw->pack_find_widget; } ],
+        [ command => 'copy (Ctrl-c)',  '-command', sub { $cw->edit_copy } ],
+        [ command => 'paste (Ctrl-v)', '-command', sub { $cw->edit_paste } ],
+        [ command => 'find (Ctrl-f)',  '-command', sub { $cw->pack_find_widget; } ],
     ];
     $menubar->cascade( -label => 'Edit', -menuitems => $edit_items );
 
+    my $option_items = [
+        [ command => 'Font',  '-command', sub { $cw->set_font(); } ],
+    ];
+    $menubar->cascade( -label => 'Options', -menuitems => $option_items );
+
     # create frame for location entry
     my $loc_frame =
         $cw->Frame( -relief => 'sunken', -borderwidth => 1 )->pack( -pady => 0, -fill => 'x' );
@@ -187,6 +229,14 @@ sub Populate {
     )->pack( -side => 'right' );
     $loc_frame->Label( -text => 'show only custom values' )->pack( -side => 'right' );
 
+    # create 'hide empty values'
+    $cw->{hide_empty_values} = 0;
+    $loc_frame->Checkbutton(
+        -variable => \$cw->{hide_empty_values},
+        -command  => sub { $cw->reload },
+    )->pack( -side => 'right' );
+    $loc_frame->Label( -text => 'hide empty values' )->pack( -side => 'right' );
+
     # add bottom frame
     my $bottom_frame = $cw->Frame->pack(qw/-pady 0 -fill both -expand 1/);
 
@@ -197,6 +247,7 @@ sub Populate {
         -columns   => 4,
         -header    => 1,
         -opencmd   => sub { $cw->open_item(@_); },
+        -closecmd  => sub { $cw->close_item(@_); },
     )->pack(qw/-fill both -expand 1 -side left/);
     $cw->{tktree} = $tree;
 
@@ -235,7 +286,7 @@ sub Populate {
     };
 
     $tree->bind( '<Return>', $b3_sub );
-    $tree->bind( '<Button-3>', $b3_sub );
+    $tree->bind( '<ButtonRelease-3>', $b3_sub );
     bind_clicks($tree,$b1_sub, $b3_sub);
 
     # bind button2 to get cut buffer content and try to store cut buffer content
@@ -243,23 +294,17 @@ sub Populate {
         my $item = $tree->nearest( $tree->pointery - $tree->rooty );
         $cw->on_cut_buffer_dump($item);
     };
-    $tree->bind( '<Button-2>', $b2_sub );
+    $tree->bind( '<ButtonRelease-2>', $b2_sub );
 
     $tree->bind( '<Control-c>', sub { $cw->edit_copy } );
     $tree->bind( '<Control-v>', sub { $cw->edit_paste } );
     $tree->bind( '<Control-f>', sub { $cw->pack_find_widget } );
 
-    # bind button2 to get cut buffer content and try to store cut buffer content
-    #my $key_sub = sub{my $item = $tree->nearest($tree->pointery - $tree->rooty) ;
-    #$cw->on_key_press($item)} ;
-    #$tree->bind('<KeyPress>', $key_sub) ;
-
     my $find_frame = $cw->create_find_widget;
 
     # create frame for message
     my $msg_label = $cw->Label(
         -textvariable => \$cw->{message},
-        -font => '-*-Helvetica-normal-R-Normal-*-*-120-*-*-*-*-*-*',
         -relief => 'sunken',
         -borderwidth => 1,
         -anchor =>'w',
@@ -269,8 +314,9 @@ sub Populate {
     $args->{-title} = $title;
     $cw->SUPER::Populate($args);
 
+    my $tk_font = $cw->Font(%{$config->{font}});
     $cw->ConfigSpecs(
-
+        -font       => ['DESCENDANTS', 'font','Font', $tk_font ],
         #-background => ['DESCENDANTS', 'background', 'Background', $background],
         #-selectbackground => [$hlist, 'selectBackground', 'SelectBackground',
         #                      $selectbackground],
@@ -289,6 +335,8 @@ sub Populate {
     $cw->Advertise( find_frame  => $find_frame );
     $cw->Advertise( msg_label   => $msg_label );
 
+    $cw->OnDestroy(sub {$cw->Parent->destroy if ref($cw->Parent) eq 'MainWindow'} );
+
     $cw->Delegates;
 }
 
@@ -383,7 +431,7 @@ sub add_help_menu {
 # Note: this callback is called by Tk::Tree *before* changing the
 # indicator. And the indicator is used by Tk::Tree to store the
 # open/close/none mode. So we can't rely on getmode for path that are
-# opening. HEnce the parameter passed to the sub stored with each
+# opening. Hence the parameter passed to the sub stored with each
 # Tk::Tree item
 sub open_item {
     my ( $cw, $path ) = @_;
@@ -395,11 +443,26 @@ sub open_item {
     # the parameter indicates that we are opening this path
     $data->[0]->(1);
 
+    $cw->show_single_list_value ($tktree, $data->[1], $path, 0);
+
     my @children = $tktree->infoChildren($path);
     $logger->trace("open_item show @children");
     map { $tktree->show( -entry => $_ ); } @children;
 }
 
+sub close_item {
+    my ( $cw, $path ) = @_;
+    my $tktree = $cw->{tktree};
+    $logger->trace("close_item on $path");
+    my $data = $tktree->infoData($path);
+
+    $cw->show_single_list_value ($tktree, $data->[1], $path, 1);
+
+    my @children = $tktree->infoChildren($path);
+    $logger->trace("close_item hide @children");
+    map { $tktree->hide( -entry => $_ ); } @children;
+}
+
 sub save_in_dir {
     my $cw = shift;
     require Tk::DirSelect;
@@ -460,6 +523,7 @@ sub save {
                 -title => 'Save error',
                 -text  => ref($@) ? $@->as_string : $@,
             )->Show;
+            $cb->($@); # indicate failure
         }
         else {
             $cw->show_message("Save done ...");
@@ -618,7 +682,8 @@ sub on_cut_buffer_dump {
 
     # display result
     $cw->reload;
-    $cw->create_element_widget('view');
+    $cw->create_element_widget($cw->{current_mode}, $tree_path);
+    $cw->open_item($tree_path);
 }
 
 # replace dot in str by _|_
@@ -666,6 +731,27 @@ sub disp_obj_elt {
     my ( $path,    $cw,       $opening, $fd_path )      = @$data_ref;
     my $tkt  = $cw->{tktree};
     my $mode = $tkt->getmode($path);
+
+    if ($cw->{show_only_custom} or $cw->{hide_empty_values}) {
+        my @new_element_list;
+        foreach my $elt ( @element_list ) {
+            my $obj = $node->fetch_element($elt);
+            if ($cw->{show_only_custom}) {
+                push @new_element_list, $elt if $node->fetch_element($elt)->has_data;
+            }
+            elsif ($cw->{hide_empty_values}) {
+                my $elt_type = $obj->get_type;
+                my $show
+                    = $elt_type eq 'hash'       ? $obj->has_data
+                    : $elt_type eq 'list'       ? $obj->has_data
+                    : $elt_type eq 'leaf'       ? length($obj->fetch(qw/mode user check no/) // '')
+                    : $elt_type eq 'check_list' ? $obj->fetch(mode => 'user')
+                    :                             1 ;
+                push @new_element_list, $elt if $show;
+            }
+        }
+        @element_list = @new_element_list;
+    }
     $logger->trace( "disp_obj_elt path $path mode $mode opening $opening " . "(@element_list)" );
 
     $cw->prune( $path, @element_list );
@@ -703,14 +789,39 @@ sub disp_obj_elt {
 
         $cw->setmode( 'node', $newpath, $eltmode, $elt_loc, $fd_path, $opening, $scan_sub );
 
+        my $obj = $node->fetch_element($elt);
         if ( $elt_type eq 'hash' ) {
-            $cw->update_hash_image( $node->fetch_element($elt), $newpath );
+            $cw->update_hash_image( $obj, $newpath );
         }
 
+        if ($elt_type eq 'hash' or $elt_type eq 'list') {
+            my $size = $obj->fetch_size;
+            $tkt->entryconfigure($newpath, -text => "$elt [$size]");
+        }
+
+        $cw->show_single_list_value ($tkt, $obj, $newpath,  $tkt->getmode($newpath) eq 'open' ? 1 : 0);
+
         $prevpath = $newpath;
     }
 }
 
+# show a list like a leaf value when the list contains *one* item
+sub show_single_list_value {
+    my ($cw, $tkt, $obj, $path, $show) = @_;
+    my $elt_type = $obj->get_type;
+
+    # leave alone element that is not a list of leaf
+    return unless $elt_type eq 'list' and $obj->get_cargo_type eq 'leaf';
+
+    $logger->trace("show_single_list_value called on ", $obj->location);
+    if ($obj->fetch_size == 1 and $show) {
+        disp_leaf(undef,[ $path, $cw ], $obj->parent, $obj->element_name, 0, $obj->fetch_with_id(0));
+    }
+    else {
+        map {$tkt->itemDelete( $path, $_ ) if $tkt->itemExists($path, $_);} qw/1 2 3/;
+    }
+}
+
 sub disp_hash {
     my ( $scanner, $data_ref, $node, $element_name, @idx ) = @_;
     my ( $path, $cw, $opening, $fd_path ) = @$data_ref;
@@ -787,6 +898,10 @@ sub disp_hash {
             $tkt->setmode( $newpath => $eltmode );
         }
 
+        # update the node gist
+        my $gist = $elt_type =~ /node/ ? $elt->fetch_with_id($idx)->fetch_gist : '';
+        $tkt->itemCreate( $newpath, 2, -text => $gist );
+
         my $elt_loc = $node_loc;
         $elt_loc .= ' ' if $elt_loc;
 
@@ -872,10 +987,19 @@ sub disp_check_list {
 
     my $value = $leaf_object->fetch;
 
-    $cw->{tktree}->itemCreate( $path, 2, -text => $cw->trim_value($value) );
+    my $tkt = $cw->{tktree};
+    $tkt->itemCreate( $path, 2, -text => $cw->trim_value($value) );
 
     my $std_v = $leaf_object->fetch('standard');
-    $cw->{tktree}->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
+    $tkt->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
+
+    if ( $std_v ne $value ) {
+        $tkt->itemCreate( $path, 1, -itemtype => 'image', -image => $cust_img );
+    }
+    else {
+        # remove image when value is identical to standard value
+        $tkt->itemDelete( $path, 1 ) if $tkt->itemExists( $path, 1 );
+    }
 }
 
 sub disp_leaf {
@@ -913,12 +1037,6 @@ sub disp_leaf {
     $tkt->itemCreate( $path, 2, -text => $cw->trim_value($value) );
 
     $tkt->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
-
-    my $meth =
-        ( $cw->{show_only_custom} and not( $is_customised or $has_error or $has_warning ) )
-        ? 'hide'
-        : 'show';
-    $tkt->$meth( entry => $path );
 }
 
 sub disp_node {
@@ -1029,11 +1147,18 @@ sub create_element_widget {
     my $widget = $widget_table{$mode}{$type}
         || die "Cannot find $mode widget for type $type";
     my @store = $mode eq 'edit' ? ( -store_cb => sub { $cw->reload(@_) } ) : ();
+    $cw->{current_mode} = $mode;
+
+    my $tk_font = $cw->cget('-font');
     $cw->{editor} = $e_frame->$widget(
         -item => $obj,
         -path => $tree_path,
-        @store
+        -font => $tk_font,
+        @store,
     );
+
+    $cw->{editor}->ConfigSpecs( -font => ['DESCENDANTS', 'font','Font', $tk_font ]);
+
     $cw->{editor}->pack( -expand => 1, -fill => 'both' );
     return $cw->{editor};
 }
@@ -1113,6 +1238,7 @@ sub edit_paste {
     }
 
     $cw->reload() if @$cut_buf;
+    $cw->create_element_widget($cw->{current_mode}, $selection);
 }
 
 sub wizard {
@@ -1133,9 +1259,11 @@ sub setup_wizard {
 
     # when wizard is run, there's no need to update editor window in
     # main widget
+    my $tk_font = $cw->cget('-font');
     return $cw->ConfigModelWizard(
         -root   => $cw->{root},
         -end_cb => $end_sub,
+        -font => $tk_font,
     );
 }
 
@@ -1312,6 +1440,11 @@ in the hash element.
 
 =back
 
+=head2 Font size and big screens
+
+Font type and size can be adjusted using menu: "Options -> Font" menu. This setup is saved in file
+C<~/.cme/config/tkui.yml>.
+
 =head2 Search
 
 Hit C<Ctrl-F> or use menu C<< Edit -> Search >> to open a search widget at the bottom 
@@ -1344,7 +1477,7 @@ items (mostly missing mandatory values).
 
 Save modified data in configuration file. The callback function is
 called only if the save was done without error. The callback is called
-without parameters.
+with C<$@> in case of failed save.
 
 =head1 TODO
 
